@@ -23,3 +23,8 @@ echo "Grant all privileges to $user user..."
 su postgres -c "psql -c \"GRANT ALL PRIVILEGES ON DATABASE template1 to $user;\"" || {
   exit 1
   }
+
+# enable the pg_trgm extension
+su postgres -c "psql -d $dbname -c \"CREATE EXTENSION IF NOT EXISTS pg_trgm;\"" || {
+  exit 1
+    }
