@@ -39,7 +39,7 @@ chmod 0700 ${gitlab_app_root}/config/secrets.yml
 
 
 echo "Precompiling assets..."
-su ${gitlab_user} -s /bin/sh -c 'bundle exec rake assets:precompile RAILS_ENV=production'
+su ${gitlab_user} -s /bin/sh -c 'bundle exec rake tmp:cache:clear assets:precompile RAILS_ENV=production'
 
 # Start gitlab
 printf "Starting GitLab...\n"
